==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QMediaServiceSupportedFormatsInterface_shell.cpp <==
#include "QMediaServiceSupportedFormatsInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QMediaServiceSupportedFormatsInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMediaServiceSupportedFormatsInterface")
    QMediaServiceSupportedFormatsInterface *_ptr = reinterpret_cast<QMediaServiceSupportedFormatsInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QMediaServiceSupportedFormatsInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QMediaServiceSupportedFormatsInterface_shell) ); }

jmethodID QMediaServiceSupportedFormatsInterface_shell::__shell_javaMethod(int pos) const { return QMediaServiceSupportedFormatsInterface_shell::__shell()->javaMethod(typeid(QMediaServiceSupportedFormatsInterface), pos); }

// emitting (writeShellConstructor)
QMediaServiceSupportedFormatsInterface_shell::QMediaServiceSupportedFormatsInterface_shell()
    : QMediaServiceSupportedFormatsInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMediaServiceSupportedFormatsInterface::QMediaServiceSupportedFormatsInterface_shell()", QMediaServiceSupportedFormatsInterface_shell::__shell())
    QMediaServiceSupportedFormatsInterface_shell::__shell()->constructed(typeid(QMediaServiceSupportedFormatsInterface));
}

// emitting (writeShellDestructor)
QMediaServiceSupportedFormatsInterface_shell::~QMediaServiceSupportedFormatsInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QMediaServiceSupportedFormatsInterface::~QMediaServiceSupportedFormatsInterface()", QMediaServiceSupportedFormatsInterface_shell::__shell())
    QMediaServiceSupportedFormatsInterface_shell::__shell()->destructed(typeid(QMediaServiceSupportedFormatsInterface));
}

void QMediaServiceSupportedFormatsInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QMediaServiceSupportedFormatsInterface_shell*>(ptr)->QMediaServiceSupportedFormatsInterface_shell::__shell()->tryDeleteShell(typeid(QMediaServiceSupportedFormatsInterface));
}

// emitting Virtual overrides (virtualFunctions)
QMultimedia::SupportEstimate QMediaServiceSupportedFormatsInterface_shell::hasSupport(const QString& mimeType0, const QStringList& codecs1) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QMediaServiceSupportedFormatsInterface::", QMediaServiceSupportedFormatsInterface_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QMultimedia::SupportEstimate  __qt_return_value = QMultimedia::SupportEstimate(0);
            QTJAMBI_TRY {
                if(jobject __java_this = QMediaServiceSupportedFormatsInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_mimeType0 = qtjambi_cast<jstring>(__jni_env, mimeType0);
                    jobject __java_codecs1 = qtjambi_cast<jobject>(__jni_env, codecs1);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_mimeType0, __java_codecs1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QMultimedia::SupportEstimate>(__jni_env, __java_return_value);
                } else {
                    QMediaServiceSupportedFormatsInterface_shell::__shell()->warnForMethod("QMediaServiceSupportedFormatsInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMediaServiceSupportedFormatsInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QMultimedia::SupportEstimate(0);
        }
    }else{
        return QMultimedia::SupportEstimate(0);
    }
}

QStringList QMediaServiceSupportedFormatsInterface_shell::supportedMimeTypes() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QMediaServiceSupportedFormatsInterface::", QMediaServiceSupportedFormatsInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QStringList  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QMediaServiceSupportedFormatsInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QMediaServiceSupportedFormatsInterface_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QStringList >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QMediaServiceSupportedFormatsInterface_shell::__shell()->warnForMethod("QMediaServiceSupportedFormatsInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMediaServiceSupportedFormatsInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QStringList();
        }
    }else{
        return QStringList();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jint QMediaServiceSupportedFormatsInterface_access::__qt_hasSupport_cref_QString_cref_QStringList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring mimeType0, jobject codecs1) const
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QString  __qt_mimeType0 = qtjambi_cast<QString>(__jni_env, mimeType0);
    const QStringList&  __qt_codecs1 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, codecs1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QMediaServiceSupportedFormatsInterface::hasSupport(const QString & mimeType, const QStringList & codecs) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QMediaServiceSupportedFormatsInterface::hasSupport(const QString & mimeType, const QStringList & codecs) const.";
    } else {
        QMultimedia::SupportEstimate __qt_return_value = hasSupport(__qt_mimeType0, __qt_codecs1);
        return __qt_return_value;
    }
}

jobject QMediaServiceSupportedFormatsInterface_access::__qt_supportedMimeTypes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QMediaServiceSupportedFormatsInterface::supportedMimeTypes() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QMediaServiceSupportedFormatsInterface::supportedMimeTypes() const.";
    } else {
        QStringList __qt_return_value = supportedMimeTypes();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QMediaServiceSupportedFormatsInterface_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QMediaServiceSupportedFormatsInterface *__qt_this = new(__qtjambi_ptr) QMediaServiceSupportedFormatsInterface_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QMediaServiceSupportedFormatsInterface_shell
void __qt_destruct_QMediaServiceSupportedFormatsInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMediaServiceSupportedFormatsInterface")
    reinterpret_cast<QMediaServiceSupportedFormatsInterface_shell*>(ptr)->~QMediaServiceSupportedFormatsInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMediaServiceSupportedFormatsInterface::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceSupportedFormatsInterface_00024Impl_initialize_1native__Lio_qt_multimedia_QMediaServiceSupportedFormatsInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMediaServiceSupportedFormatsInterface::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMediaServiceSupportedFormatsInterface_0, sizeof(QMediaServiceSupportedFormatsInterface_shell), typeid(QMediaServiceSupportedFormatsInterface), true, &deleter_QMediaServiceSupportedFormatsInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMediaServiceSupportedFormatsInterface::hasSupport(QString,QStringList)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceSupportedFormatsInterface_00024Impl_00024ConcreteWrapper_hasSupport_1native_1cref_1QString_1cref_1QStringList_1constfct__JLjava_lang_String_2Ljava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jstring mimeType0,
 jobject codecs1)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QMediaServiceSupportedFormatsInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QMediaServiceSupportedFormatsInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMediaServiceSupportedFormatsInterface::hasSupport(QString,QStringList)const", __qt_this)
        __java_return_value = static_cast<const QMediaServiceSupportedFormatsInterface_access*>(__qt_this)->__qt_hasSupport_cref_QString_cref_QStringList_constfct(__jni_env, __this_nativeId, mimeType0, codecs1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMediaServiceSupportedFormatsInterface::supportedMimeTypes()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceSupportedFormatsInterface_00024Impl_00024ConcreteWrapper_supportedMimeTypes_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMediaServiceSupportedFormatsInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QMediaServiceSupportedFormatsInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMediaServiceSupportedFormatsInterface::supportedMimeTypes()const", __qt_this)
        __java_return_value = static_cast<const QMediaServiceSupportedFormatsInterface_access*>(__qt_this)->__qt_supportedMimeTypes(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMediaServiceSupportedFormatsInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QMediaServiceSupportedFormatsInterface>("QMediaServiceSupportedFormatsInterface", "io/qt/multimedia/QMediaServiceSupportedFormatsInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "hasSupport", "(Ljava/lang/String;Ljava/util/Collection;)Lio/qt/multimedia/QMultimedia$SupportEstimate;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "supportedMimeTypes", "()Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QMediaServiceSupportedFormatsInterface, {
        ConstructorInfo(&__qt_construct_QMediaServiceSupportedFormatsInterface_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMediaServiceSupportedFormatsInterface);
    registerSizeOfShell(typeId, sizeof(QMediaServiceSupportedFormatsInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QMediaServiceSupportedFormatsInterface* _object = dynamic_cast<QMediaServiceSupportedFormatsInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QMediaServiceSupportedFormatsInterface *object = reinterpret_cast<QMediaServiceSupportedFormatsInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QMediaServiceSupportedFormatsInterface *object = reinterpret_cast<const QMediaServiceSupportedFormatsInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QMediaServiceSupportedFormatsInterface_shell.cpp <==
#include "QMediaServiceSupportedFormatsInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QMediaServiceSupportedFormatsInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMediaServiceSupportedFormatsInterface")
    QMediaServiceSupportedFormatsInterface *_ptr = reinterpret_cast<QMediaServiceSupportedFormatsInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QMediaServiceSupportedFormatsInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QMediaServiceSupportedFormatsInterface_shell) ); }

jmethodID QMediaServiceSupportedFormatsInterface_shell::__shell_javaMethod(int pos) const { return QMediaServiceSupportedFormatsInterface_shell::__shell()->javaMethod(typeid(QMediaServiceSupportedFormatsInterface), pos); }

// emitting (writeShellConstructor)
QMediaServiceSupportedFormatsInterface_shell::QMediaServiceSupportedFormatsInterface_shell()
    : QMediaServiceSupportedFormatsInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMediaServiceSupportedFormatsInterface::QMediaServiceSupportedFormatsInterface_shell()", QMediaServiceSupportedFormatsInterface_shell::__shell())
    QMediaServiceSupportedFormatsInterface_shell::__shell()->constructed(typeid(QMediaServiceSupportedFormatsInterface));
}

// emitting (writeShellDestructor)
QMediaServiceSupportedFormatsInterface_shell::~QMediaServiceSupportedFormatsInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QMediaServiceSupportedFormatsInterface::~QMediaServiceSupportedFormatsInterface()", QMediaServiceSupportedFormatsInterface_shell::__shell())
    QMediaServiceSupportedFormatsInterface_shell::__shell()->destructed(typeid(QMediaServiceSupportedFormatsInterface));
}

void QMediaServiceSupportedFormatsInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QMediaServiceSupportedFormatsInterface_shell*>(ptr)->QMediaServiceSupportedFormatsInterface_shell::__shell()->tryDeleteShell(typeid(QMediaServiceSupportedFormatsInterface));
}

// emitting Virtual overrides (virtualFunctions)
QMultimedia::SupportEstimate QMediaServiceSupportedFormatsInterface_shell::hasSupport(const QString& mimeType0, const QStringList& codecs1) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QMediaServiceSupportedFormatsInterface::", QMediaServiceSupportedFormatsInterface_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QMultimedia::SupportEstimate  __qt_return_value = QMultimedia::SupportEstimate(0);
            QTJAMBI_TRY {
                if(jobject __java_this = QMediaServiceSupportedFormatsInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_mimeType0 = qtjambi_cast<jstring>(__jni_env, mimeType0);
                    jobject __java_codecs1 = qtjambi_cast<jobject>(__jni_env, codecs1);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_mimeType0, __java_codecs1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QMultimedia::SupportEstimate>(__jni_env, __java_return_value);
                } else {
                    QMediaServiceSupportedFormatsInterface_shell::__shell()->warnForMethod("QMediaServiceSupportedFormatsInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMediaServiceSupportedFormatsInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QMultimedia::SupportEstimate(0);
        }
    }else{
        return QMultimedia::SupportEstimate(0);
    }
}

QStringList QMediaServiceSupportedFormatsInterface_shell::supportedMimeTypes() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QMediaServiceSupportedFormatsInterface::", QMediaServiceSupportedFormatsInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QStringList  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QMediaServiceSupportedFormatsInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QMediaServiceSupportedFormatsInterface_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QStringList >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QMediaServiceSupportedFormatsInterface_shell::__shell()->warnForMethod("QMediaServiceSupportedFormatsInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMediaServiceSupportedFormatsInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QStringList();
        }
    }else{
        return QStringList();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jint QMediaServiceSupportedFormatsInterface_access::__qt_hasSupport_cref_QString_cref_QStringList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring mimeType0, jobject codecs1) const
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QString  __qt_mimeType0 = qtjambi_cast<QString>(__jni_env, mimeType0);
    const QStringList&  __qt_codecs1 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, codecs1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QMediaServiceSupportedFormatsInterface::hasSupport(const QString & mimeType, const QStringList & codecs) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QMediaServiceSupportedFormatsInterface::hasSupport(const QString & mimeType, const QStringList & codecs) const.";
    } else {
        QMultimedia::SupportEstimate __qt_return_value = hasSupport(__qt_mimeType0, __qt_codecs1);
        return __qt_return_value;
    }
}

jobject QMediaServiceSupportedFormatsInterface_access::__qt_supportedMimeTypes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QMediaServiceSupportedFormatsInterface::supportedMimeTypes() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QMediaServiceSupportedFormatsInterface::supportedMimeTypes() const.";
    } else {
        QStringList __qt_return_value = supportedMimeTypes();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QMediaServiceSupportedFormatsInterface()
void __qt_construct_QMediaServiceSupportedFormatsInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMediaServiceSupportedFormatsInterface()")
    Q_UNUSED(__java_arguments)
    QMediaServiceSupportedFormatsInterface *__qt_this = new(__qtjambi_ptr) QMediaServiceSupportedFormatsInterface_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QMediaServiceSupportedFormatsInterface::QMediaServiceSupportedFormatsInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceSupportedFormatsInterface_00024Impl_initialize_1native__Lio_qt_multimedia_QMediaServiceSupportedFormatsInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMediaServiceSupportedFormatsInterface::QMediaServiceSupportedFormatsInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMediaServiceSupportedFormatsInterface, sizeof(QMediaServiceSupportedFormatsInterface_shell), typeid(QMediaServiceSupportedFormatsInterface), true, &deleter_QMediaServiceSupportedFormatsInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QMediaServiceSupportedFormatsInterface_shell
void __qt_destruct_QMediaServiceSupportedFormatsInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMediaServiceSupportedFormatsInterface")
    reinterpret_cast<QMediaServiceSupportedFormatsInterface_shell*>(ptr)->~QMediaServiceSupportedFormatsInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMediaServiceSupportedFormatsInterface::hasSupport(QString,QStringList)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceSupportedFormatsInterface_00024Impl_00024ConcreteWrapper_hasSupport_1native_1cref_1QString_1cref_1QStringList_1constfct__JLjava_lang_String_2Ljava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jstring mimeType0,
 jobject codecs1)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QMediaServiceSupportedFormatsInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QMediaServiceSupportedFormatsInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMediaServiceSupportedFormatsInterface::hasSupport(QString,QStringList)const", __qt_this)
        __java_return_value = static_cast<const QMediaServiceSupportedFormatsInterface_access*>(__qt_this)->__qt_hasSupport_cref_QString_cref_QStringList_constfct(__jni_env, __this_nativeId, mimeType0, codecs1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMediaServiceSupportedFormatsInterface::supportedMimeTypes()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QMediaServiceSupportedFormatsInterface_00024Impl_00024ConcreteWrapper_supportedMimeTypes_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMediaServiceSupportedFormatsInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QMediaServiceSupportedFormatsInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMediaServiceSupportedFormatsInterface::supportedMimeTypes()const", __qt_this)
        __java_return_value = static_cast<const QMediaServiceSupportedFormatsInterface_access*>(__qt_this)->__qt_supportedMimeTypes_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMediaServiceSupportedFormatsInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QMediaServiceSupportedFormatsInterface>("QMediaServiceSupportedFormatsInterface", "io/qt/multimedia/QMediaServiceSupportedFormatsInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "hasSupport", "(Ljava/lang/String;Ljava/util/Collection;)Lio/qt/multimedia/QMultimedia$SupportEstimate;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "supportedMimeTypes", "()Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QMediaServiceSupportedFormatsInterface, {
        ConstructorInfo(&__qt_construct_QMediaServiceSupportedFormatsInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMediaServiceSupportedFormatsInterface);
    registerSizeOfShell(typeId, sizeof(QMediaServiceSupportedFormatsInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QMediaServiceSupportedFormatsInterface* _object = dynamic_cast<QMediaServiceSupportedFormatsInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QMediaServiceSupportedFormatsInterface *object = reinterpret_cast<QMediaServiceSupportedFormatsInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QMediaServiceSupportedFormatsInterface *object = reinterpret_cast<const QMediaServiceSupportedFormatsInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
